lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:	Wed, 16 May 2012 20:59:15 +0800
From:	Feng Tang <feng.tang@...el.com>
To:	acme@...hat.com, mingo@...e.hu, a.p.zijlstra@...llo.nl,
	robert.richter@....com, ak@...ux.intel.com,
	linux-kernel@...r.kernel.org
Cc:	Feng Tang <feng.tang@...el.com>
Subject: [PATCH 3/3] perf script/python: Pass thread/dso name and symbol info to event handler in python

Signed-off-by: Feng Tang <feng.tang@...el.com>
---
 .../util/scripting-engines/trace-event-python.c    |   11 ++++++++++-
 1 files changed, 10 insertions(+), 1 deletions(-)

diff --git a/tools/perf/util/scripting-engines/trace-event-python.c b/tools/perf/util/scripting-engines/trace-event-python.c
index a202881..c96f5e2 100644
--- a/tools/perf/util/scripting-engines/trace-event-python.c
+++ b/tools/perf/util/scripting-engines/trace-event-python.c
@@ -336,6 +336,7 @@ static void python_process_general_event(union perf_event *pevent __unused,
 	static char handler_name[64];
 	unsigned n = 0;
 	void *data = sample->raw_data;
+	struct thread *thread = al->thread;
 
 	t = PyTuple_New(MAX_FIELDS);
 	if (!t)
@@ -348,13 +349,21 @@ static void python_process_general_event(union perf_event *pevent __unused,
 		goto exit;
 	}
 
 	/* Pass 3 parameters: event_attr, perf_sample, raw data, thread name */
 	PyTuple_SetItem(t, n++, PyString_FromStringAndSize(
 			(const char *)&evsel->attr, sizeof(evsel->attr)));
 	PyTuple_SetItem(t, n++, PyString_FromStringAndSize(
 			(const char *)sample, sizeof(*sample)));
 	PyTuple_SetItem(t, n++, PyString_FromStringAndSize(
 			data, sample->raw_size));
+	PyTuple_SetItem(t, n++, PyString_FromString(thread->comm));
+	PyTuple_SetItem(t, n++, PyString_FromString(al->map->dso->name));
+
+	/* Pass the resolved symbol if there is, othersize pass "Unkown" */
+	if (al->sym)
+		PyTuple_SetItem(t, n++, PyString_FromString(al->sym->name));
+	else
+		PyTuple_SetItem(t, n++, PyString_FromString("Unknown"));
 
 	if (_PyTuple_Resize(&t, n) == -1)
 		Py_FatalError("error resizing Python tuple");
@@ -348,13 +349,21 @@ static void python_process_general_event(union perf_event *pevent __unused,
 	}
 
-	/* Pass 3 parameters: event_attr, perf_sample, raw data, thread name */
+	/* Pass parameters: attr, perf_sample, raw data, thread and dso name */
 	PyTuple_SetItem(t, n++, PyString_FromStringAndSize(
 			(const char *)&evsel->attr, sizeof(evsel->attr)));
-- 
1.7.1

--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Powered by blists - more mailing lists